==> iTop-3.2.0-2-14758.zip: web/dictionaries/ui/layouts/activity-panel/pl.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('PL PL', 'Polish', 'Polski', [
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panel aktywności',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Kliknij, aby otworzyć panel aktywności',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Utwórz nowy wpis w dzienniku',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Zamknij',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Załaduj wszystkie poprzednie wpisy',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Załaduj więcej wpisów',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Naciskając przycisk "zapisz", prześlesz wpisy dla wszystkich edytowanych logów jednocześnie.',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Zapisywanie wielu dzienników',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Tu jest spokojnie, jeszcze nie ma aktywności',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Kliknij, aby otworzyć zakładkę powiadomień i uzyskać więcej informacji',
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Rozwiń',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Zwiń',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Aktywność',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Szkice',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Zamknij wszystkie wpisy',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Otwórz wszystkie wpisy',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Edycje',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Pokaż / ukryj edycje pól na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Wybierz, które dzienniki mają być wyświetlane na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logi',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Pokaż / ukryj wpisy logów na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Zmiany stanu',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Pokaż / ukryj zmiany stanu na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Liczba osób wchodzących w interakcję w widocznych wpisach',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Liczba wiadomości w widocznym dzienniku(ach)',
]);

==> iTop-3.2.2-1-17851.zip: web/dictionaries/ui/layouts/activity-panel/pl.dictionary.itop.activity-panel.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('PL PL', 'Polish', 'Polski', array(
	'UI:Layout:ActivityPanel:SizeToggler:Expand:Tooltip' => 'Rozwiń',
	'UI:Layout:ActivityPanel:SizeToggler:Reduce:Tooltip' => 'Zwiń',
	'UI:Layout:ActivityPanel:DisplayToggler:Close:Tooltip' => 'Zamknij',
	'UI:Layout:ActivityPanel:LoadMoreEntries:Tooltip' => 'Załaduj więcej wpisów',
	'UI:Layout:ActivityPanel:LoadAllEntries:Tooltip' => 'Załaduj wszystkie poprzednie wpisy',
	'UI:Layout:ActivityPanel:Tab:Activity:Title' => 'Aktywność',
	'UI:Layout:ActivityPanel:Tab:Log:DraftIndicator:Tooltip' => 'Szkice',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Title' => 'Logi',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Tooltip' => 'Pokaż / ukryj wpisy logów na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Logs:Menu:Hint' => 'Wybierz, które dzienniki mają być wyświetlane na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Title' => 'Zmiany stanu',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Transitions:Tooltip' => 'Pokaż / ukryj zmiany stanu na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Title' => 'Edycje',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Filter:Edits:Tooltip' => 'Pokaż / ukryj edycje pól na tej karcie',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:OpenAll:Tooltip' => 'Otwórz wszystkie wpisy',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Action:CloseAll:Tooltip' => 'Zamknij wszystkie wpisy',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:AuthorsCount:Tooltip' => 'Liczba osób wchodzących w interakcję w widocznych wpisach',
	'UI:Layout:ActivityPanel:Tab:Toolbar:Info:MessagesCount:Tooltip' => 'Liczba wiadomości w widocznym dzienniku(ach)',
	'UI:Layout:ActivityPanel:ComposeButton:Tooltip' => 'Utwórz nowy wpis w dzienniku',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Title' => 'Zapisywanie wielu dzienników',
	'UI:Layout:ActivityPanel:MultipleEntriesSaveConfirmation:Explanation' => 'Naciskając przycisk "zapisz", prześlesz wpisy dla wszystkich edytowanych logów jednocześnie.',
	'UI:Layout:ActivityPanel:NotificationEntry:MessageLink:Tooltip' => 'Kliknij, aby otworzyć zakładkę powiadomień i uzyskać więcej informacji',
	'UI:Layout:ActivityPanel:NoEntry:Placeholder:Hint' => 'Tu jest spokojnie, jeszcze nie ma aktywności',
	'UI:Layout:ActivityPanel:ClosedCover:Title' => 'Panel aktywności',
	'UI:Layout:ActivityPanel:ClosedCover:Tooltip' => 'Kliknij, aby otworzyć panel aktywności',
));
